==> aws-cdk-lib-2.0.0-rc.6-sources.jar: software/amazon/awscdk/services/dynamodb/IScalableTableAttribute.java <==
package software.amazon.awscdk.services.dynamodb;

/**
 * (experimental) Interface for scalable attributes.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-06-02T09:55:16.916Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_dynamodb.IScalableTableAttribute")
@software.amazon.jsii.Jsii.Proxy(IScalableTableAttribute.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface IScalableTableAttribute extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Add scheduled scaling for this scaling attribute.
     * <p>
     * @param id This parameter is required.
     * @param actions This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    void scaleOnSchedule(final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.applicationautoscaling.ScalingSchedule actions);

    /**
     * (experimental) Scale out or in to keep utilization at a given level.
     * <p>
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    void scaleOnUtilization(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.dynamodb.UtilizationScalingProps props);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.dynamodb.IScalableTableAttribute.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * (experimental) Add scheduled scaling for this scaling attribute.
         * <p>
         * @param id This parameter is required.
         * @param actions This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public final void scaleOnSchedule(final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.applicationautoscaling.ScalingSchedule actions) {
            software.amazon.jsii.Kernel.call(this, "scaleOnSchedule", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(actions, "actions is required") });
        }

        /**
         * (experimental) Scale out or in to keep utilization at a given level.
         * <p>
         * @param props This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public final void scaleOnUtilization(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.dynamodb.UtilizationScalingProps props) {
            software.amazon.jsii.Kernel.call(this, "scaleOnUtilization", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
        }
    }

    /**
     * Internal default implementation for {@link IScalableTableAttribute}.
     */
    @software.amazon.jsii.Internal
    interface Jsii$Default extends IScalableTableAttribute {

        /**
         * (experimental) Add scheduled scaling for this scaling attribute.
         * <p>
         * @param id This parameter is required.
         * @param actions This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        default void scaleOnSchedule(final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.applicationautoscaling.ScalingSchedule actions) {
            software.amazon.jsii.Kernel.call(this, "scaleOnSchedule", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(actions, "actions is required") });
        }

        /**
         * (experimental) Scale out or in to keep utilization at a given level.
         * <p>
         * @param props This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        default void scaleOnUtilization(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.dynamodb.UtilizationScalingProps props) {
            software.amazon.jsii.Kernel.call(this, "scaleOnUtilization", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/dynamodb/IScalableTableAttribute.java <==
package software.amazon.awscdk.services.dynamodb;

/**
 * Interface for scalable attributes.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:08.914Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_dynamodb.IScalableTableAttribute")
@software.amazon.jsii.Jsii.Proxy(IScalableTableAttribute.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IScalableTableAttribute extends software.amazon.jsii.JsiiSerializable {

    /**
     * Add scheduled scaling for this scaling attribute.
     * <p>
     * @param id This parameter is required.
     * @param actions This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    void scaleOnSchedule(final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.applicationautoscaling.ScalingSchedule actions);

    /**
     * Scale out or in to keep utilization at a given level.
     * <p>
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    void scaleOnUtilization(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.dynamodb.UtilizationScalingProps props);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.dynamodb.IScalableTableAttribute.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Add scheduled scaling for this scaling attribute.
         * <p>
         * @param id This parameter is required.
         * @param actions This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public final void scaleOnSchedule(final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.applicationautoscaling.ScalingSchedule actions) {
            software.amazon.jsii.Kernel.call(this, "scaleOnSchedule", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(actions, "actions is required") });
        }

        /**
         * Scale out or in to keep utilization at a given level.
         * <p>
         * @param props This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public final void scaleOnUtilization(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.dynamodb.UtilizationScalingProps props) {
            software.amazon.jsii.Kernel.call(this, "scaleOnUtilization", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
        }
    }

    /**
     * Internal default implementation for {@link IScalableTableAttribute}.
     */
    @software.amazon.jsii.Internal
    interface Jsii$Default extends IScalableTableAttribute {

        /**
         * Add scheduled scaling for this scaling attribute.
         * <p>
         * @param id This parameter is required.
         * @param actions This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        default void scaleOnSchedule(final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.applicationautoscaling.ScalingSchedule actions) {
            software.amazon.jsii.Kernel.call(this, "scaleOnSchedule", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(actions, "actions is required") });
        }

        /**
         * Scale out or in to keep utilization at a given level.
         * <p>
         * @param props This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        default void scaleOnUtilization(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.dynamodb.UtilizationScalingProps props) {
            software.amazon.jsii.Kernel.call(this, "scaleOnUtilization", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
        }
    }
}
